#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cabal-doctest
version:              1.0.11
visibility:           public
id:                   cabal-doctest-1.0.11-4qdhmVZgzSm3qT3WUn1vx1
key:                  cabal-doctest-1.0.11-4qdhmVZgzSm3qT3WUn1vx1
license:              BSD-3-Clause
copyright:            (c) 2017-2020 Oleg Grenrus, 2020- package maintainers
maintainer:           Max Ulidtko <ulidtko@gmail.com>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/ulidtko/cabal-doctest
synopsis:             A Setup.hs helper for running doctests
description:
    As of now (end of 2024), there isn'\''t @cabal doctest@
    command. Yet, to properly work, @doctest@ needs plenty of configuration.
    This library provides the common bits for writing a custom @Setup.hs@.

category:             Distribution
abi:                  cc10ece934dd5cdd8b967f9fce74cc9d
exposed:              True
exposed-modules:      Distribution.Extra.Doctest
import-dirs:          /usr/lib/ghc-9.6.6/site-local/cabal-doctest-1.0.11
library-dirs:         /usr/lib/ghc-9.6.6/site-local/cabal-doctest-1.0.11
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/cabal-doctest-1.0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cabal-doctest
hs-libraries:         HScabal-doctest-1.0.11-4qdhmVZgzSm3qT3WUn1vx1
depends:
    Cabal-3.10.3.0 base-4.18.2.1 directory-1.3.8.5 filepath-1.4.300.1

haddock-interfaces:
    /usr/share/doc/haskell-cabal-doctest/html/cabal-doctest.haddock

haddock-html:         /usr/share/doc/haskell-cabal-doctest/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

